package com.huimv.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.admin.common.utils.Result;
import com.huimv.admin.common.utils.ResultCode;
import com.huimv.admin.entity.ProtBatch;
import com.huimv.admin.entity.ProtSheepInfo;
import com.huimv.admin.entity.vo.ProtBatchAddVo;
import com.huimv.admin.mapper.ProtBatchMapper;
import com.huimv.admin.mapper.ProtSheepInfoMapper;
import com.huimv.admin.service.IProtBatchService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 生产管理批次记录 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-08-13
 */
@Service
public class ProtBatchServiceImpl extends ServiceImpl<ProtBatchMapper, ProtBatch> implements IProtBatchService {

    @Autowired
    private ProtBatchMapper batchMapper;
    @Autowired
    private ProtSheepInfoMapper sheepInfoMapper;

    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String batchNum = paramsMap.get("batchNum");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        Page<ProtBatch> page = new Page(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        QueryWrapper<ProtBatch> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).like(StringUtils.isNotBlank(batchNum), "batch_num", batchNum);
        return new Result(ResultCode.SUCCESS, batchMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result addBatch(ProtBatchAddVo batchAddVo) {
        Integer dayCount = 0;
        BigDecimal weight = BigDecimal.ZERO;
        Integer number = batchAddVo.getSheepInfos().size();
        ProtBatch protBatch = new ProtBatch();
        protBatch.setBatchNum(batchAddVo.getBatchNum());
        protBatch.setNumber(number);
        protBatch.setFarmId(batchAddVo.getFarmId());
        protBatch.setRegisterUser(batchAddVo.getRegisterUser());
        protBatch.setCreateTime(batchAddVo.getCreateTime());
        List<ProtSheepInfo> sheepInfos = batchAddVo.getSheepInfos();
        for (ProtSheepInfo sheepInfo : sheepInfos) {
            dayCount = dayCount + sheepInfo.getSheepDay();
            BigDecimal db = new BigDecimal(sheepInfo.getSheepWeight());
            weight = weight.add(db);
            sheepInfo.setBatchNum(batchAddVo.getBatchNum());
            sheepInfoMapper.updateById(sheepInfo);
        }
        BigDecimal num2 = new BigDecimal(number);
        BigDecimal avgWeight = weight.divide(num2);//
        protBatch.setAvgWeight(avgWeight.doubleValue());
        protBatch.setAvgDay(dayCount / number);
        batchMapper.insert(protBatch);
        return new Result(ResultCode.SUCCESS);
    }
}
