package com.huimv.admin.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.huimv.admin.common.utils.DataUill;
import com.huimv.admin.common.utils.Result;
import com.huimv.admin.common.utils.ResultCode;
import com.huimv.admin.entity.ProtEnvData;
import com.huimv.admin.mapper.ProtEnvDataMapper;
import com.huimv.admin.service.IProtEnvDataService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 生产管理环境监测 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-08-13
 */
@Service
public class ProtEnvDataServiceImpl extends ServiceImpl<ProtEnvDataMapper, ProtEnvData> implements IProtEnvDataService {

    @Autowired
    private ProtEnvDataMapper envDataMapper;

    @Override
    public Result listData(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String unitId = paramsMap.get("unitId");
        String startDate = paramsMap.get("startDate");
        String endDate = paramsMap.get("endDate");
        QueryWrapper<ProtEnvData> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).eq("unit_id", unitId).between(StringUtils.isNotBlank(startDate), "create_time", startDate, endDate);
        return new Result(ResultCode.SUCCESS,envDataMapper.selectList(queryWrapper));
    }

    @Override
    public Result listHistory(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String unitId = paramsMap.get("unitId");
        String timeType = paramsMap.get("timeType");

        if ("".equals(timeType) || null == timeType) {
            timeType = "1";
        }
        QueryWrapper<ProtEnvData> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).eq("unit_id", unitId);
        //今日
        List<ProtEnvData> protEnvData = null;
        if ("1".equals(timeType)) {
            Date timesmorning = DataUill.getTimesmorning();
            queryWrapper.ge("create_time", timesmorning);
            protEnvData = envDataMapper.listDataDay(queryWrapper);
        }
        //本周
        else if ("2".equals(timeType)) {
            DateTime dateTime = DateUtil.beginOfWeek(new Date());
            queryWrapper.ge("create_time", dateTime);
            protEnvData = envDataMapper.listData(queryWrapper);
        }
        //本月
        else if ("3".equals(timeType)) {
            Date monthmorning = DataUill.getTimesMonthmorning();
            queryWrapper.ge("create_time", monthmorning);
            protEnvData=envDataMapper.listData(queryWrapper);
        }
        //自定义
        else if ("4".equals(timeType)) {
            String startDate = paramsMap.get("startDate");
            String endDate = paramsMap.get("endDate");
            queryWrapper.between("create_time", startDate,endDate);
            protEnvData=envDataMapper.listData(queryWrapper);
        }
        return new Result(ResultCode.SUCCESS, protEnvData);
    }
}
